﻿//-----------------------------------------------------------------------
// <copyright file="MainMenu.cs">
// </copyright>
//-----------------------------------------------------------------------
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using DataManagement;

namespace Gui
{
    /// <summary>
    /// メインメニュー画面です。
    /// </summary>
    public partial class MainMenu : Form
    {
        #region フィールド
        /// <summary>
        /// 問題管理を扱います。
        /// </summary>
        private QuestionManager qsm;
        #endregion

        #region コンストラクタ
        /// <summary>
        /// ウィンドウを表示させます。
        /// </summary>
        public MainMenu()
        {
#if !DEBUG
            Gui.Properties.Settings.Default.Question_Path = "fe_data.xml";
#endif

            // コンポーネントを初期化
            this.InitializeComponent();

            // 問題管理を初期化
            this.qsm = new QuestionManager(Gui.Properties.Settings.Default.Question_Path);
        }
        #endregion

        #region イベントハンドラ
        /// <summary>
        /// 問題登録ボタンがクリックされた時
        /// </summary>
        /// <param name="sender">イベントの送信元です。</param>
        /// <param name="e">発信されたイベントです。</param>
        private void btnQuestionEntry_Click(object sender, EventArgs e)
        {
            QuestionEntry cqte = new QuestionEntry(this.qsm);
            cqte.ShowDialog();
        }

        /// <summary>
        /// 問題回答ボタンがクリックされた時
        /// </summary>
        /// <param name="sender">イベントの送信元です。</param>
        /// <param name="e">発信されたイベントです。</param>
        private void btnQuestionSolve_Click(object sender, EventArgs e)
        {
            ModeSelect cmds = new ModeSelect(this.qsm);
            cmds.ShowDialog();
        }

        /// <summary>
        /// 終了ボタンがクリックされた時
        /// </summary>
        /// <param name="sender">イベントの送信元です。</param>
        /// <param name="e">発信されたイベントです。</param>
        private void btnEnd_Click(object sender, EventArgs e)
        {
            // 宣言
            DialogResult dlr;

            // ダイアログ結果を初期化
            dlr = MessageBox.Show(Gui.Properties.Message2.C_002, Properties.MessageTitle2.T_002, MessageBoxButtons.YesNo, MessageBoxIcon.Question);

            if (dlr == DialogResult.Yes)
            {
                // この画面を閉じる
                this.Close();
            }
        }

        /// <summary>
        /// メインメニュー画面を閉じる時
        /// </summary>
        /// <param name="sender">イベントの送信元です。</param>
        /// <param name="e">発信されたイベントです。</param>
        private void MainMenu_FormClosed(object sender, FormClosedEventArgs e)
        {
            // 問題データをセーブ
            this.qsm.SaveQuestionData();
        }

        #endregion
    }
}